using System;
using System.Collections;
using System.Collections.Generic;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinDataSource;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinMaskedEdit;
using ColumnHeader=Infragistics.Win.UltraWinGrid.ColumnHeader;

namespace EditAsTime
{
    public partial class Form1 : Form
    {
        private readonly List<DateTime> data = new List<DateTime>();

        /// <summary>
        /// Initializes a new instance of the <see cref="Form1"/> class.
        /// </summary>
        public Form1()
        {
            InitializeComponent();
            UltraGridColumn valueCol = grid_.DisplayLayout.Bands[0].Columns["Value"];
            valueCol.SortComparer = new CustomComparer();

            BuildTestData();
            PopulateDataSource();
        }

        /// <summary>
        /// Builds the test data.
        /// </summary>
        private void BuildTestData()
        {
            data.Add(new DateTime(1900, 1, 1, 8, 0, 0));
            data.Add(new DateTime(1922, 1, 1, 12, 0, 0));
            data.Add(new DateTime(1944, 1, 1, 16, 0, 0));
            data.Add(new DateTime(1956, 1, 1, 18, 0, 0));
            data.Add(new DateTime(1968, 1, 1, 20, 0, 0));
        }

        /// <summary>
        /// Populates the data source.
        /// </summary>
        private void PopulateDataSource()
        {
            int i = 0;
            foreach (DateTime time in data)
            {
                UltraDataRow row = dataSource_.Rows.Add();
                row["Start"] = time;
                row["End"] = time;
                switch (i)
                {
                    case  0 :
                        row["Value"] = "2";
                        break;
                    case 1:
                        row["Value"] = "21";
                        break;
                    case 2:
                        row["Value"] = "90";
                        break;
                    case 3:
                        row["Value"] = "978";
                        break;
                    case 4:
                        row["Value"] = "98";
                        break;
                }
                i++;
            }
        }


        private class CustomComparer : IComparer
        {
            int IComparer.Compare(object x, object y)
            {
                UltraGridCell xCell = (UltraGridCell)x;
                UltraGridCell yCell = (UltraGridCell)y;

                double val1;
                double val2;
                double.TryParse(xCell.Value.ToString(), out val1);
                double.TryParse(yCell.Value.ToString(), out val2);

                return val1.CompareTo(val2);
            }
        }
    }
}